# Documentation for `ResultsHandler`
::: photonai.processing.ResultsHandler
    selection:
      members:
        - __init__
        - load_from_file
        - load_from_mongodb
        - get_methods
        - get_performance_table
        - get_config_evaluations
